# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litecms/davepro/podcast/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Litecms\\Davepro/podcast\\": "packages/litecms/davepro/podcast/src",
            "Litecms\\Davepro/podcast\\Seeders\\": "packages/litecms/davepro/podcast/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litecms\Davepro/podcast\Providers\Davepro/podcastServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Davepro/podcast'  => Litecms\Davepro/podcast\Facades\Davepro/podcast::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litecms\\Davepro/podcast\\Seeders\\Davepro/podcastTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litecms\Davepro/podcast\Providers\Davepro/podcastServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litecms\Davepro/podcast\Providers\Davepro/podcastServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litecms\Davepro/podcast\Providers\Davepro/podcastServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/davepro/podcast/{modulename}

**User**

    http://path-to-route-folder/user/davepro/podcast/{modulename}

**Public**

    http://path-to-route-folder/davepro/podcasts


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/davepro/podcast/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/davepro/podcast/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/davepro/podcast/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/davepro/podcast/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/davepro/podcast/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/davepro/podcast/{modulename}/{slug}
    METHOD: GET